(:~
 : Constructs basic HTML webpage.
 : @returns HTML
 :)
declare function local:html( $conferences as element(conf)*, $inproceedings as element(inproceedings)* ) as element(html)
{
  <html lang="en">
    <head>
      <meta charset="utf-8"/>
      <title>OpenProceedings 3000</title>
      <link href="main.css" rel="stylesheet"/>
    </head>
    <body>
      <div class="header">
        <h1 class="headline">OpenProceedings 3000</h1>
      </div>
      <div class="navigation" id="navigation">
        <h2 class="navigation-headline">Navigation</h2>
        <ul>
          {
            for $conference in $conferences
            order by $conference/proceedings/year descending
            return
              local:conference_navigation_link($conference)
          }
        </ul>
      </div>
      <div class="conferences">
        <h2 class="conferences-headline">Conferences</h2>
        {
          for $conference in $conferences
          let $proceedings := $conference/proceedings
          order by $proceedings/year descending
          return local:conference($conference, $inproceedings)
        }
      </div>
    </body>
  </html>
};

declare function local:conference_navigation_link( $conference as element(conf)* ) as element(li)+
{
  (
    <li>
      <a href="#{$conference/@key/data()}">
        {concat($conference/proceedings/booktitle/text()," ", $conference/proceedings/year/text())}
      </a>
    </li>
  )
};

declare function local:conference( $conference as element(conf)*, $inproceedings as element(inproceedings)* ) as element(div)+
{
  (
    <div class="conference" id="{$conference/@key/data()}">
      <h3 class="conference-title">{$conference/proceedings/title/text()}</h3>
      <a href="#navigation">Back to navigation</a>
      <h4 class="sessions-headline">Research Sessions</h4>
      {
        for $session in $conference/session
        return local:session($session, $inproceedings)
      }
    </div>
  )
};

declare function local:session( $session as element(session)*, $inproceedings as element(inproceedings)* ) as element(div)+
{
  (
    <div class="session">
      <h5 class="session-title">{$session/@name/data()}</h5>
      {
        for $paper in $session/paper
        let $inproceeding := $inproceedings[@key = $paper/@key]
        return local:paper($inproceeding)
      }
    </div>
  )
};

declare function local:paper( $inproceedings as element(inproceedings) ) as element(div)+
{
  (
    <div class="paper">
      <h6 class="paper-title">{$inproceedings/title/text()}</h6>
      <p class="authors">
        {
          let $authors := $inproceedings/author
          return string-join($authors, ", ")
        }
      </p>
    </div>
  )
};

(: --------- Main entry point ------- :)
let $edbt-confs-with-sessions := doc('./xml/edbt-confs-with-sessions.xml')
let $edbt-conferences := $edbt-confs-with-sessions/confs/conf[proceedings/booktitle eq 'EDBT']

let $dblp-edbt := doc('./xml/dblp-edbt.xml')
let $inproceedings := $dblp-edbt/edbt/inproceedings

let $html := local:html($edbt-conferences, $inproceedings)
return file:write('D:/Studium/DBLP/data/html/home.html', $html)
